opiClose: Calls opiClose_for_MACHINE as appropriate.

View source: R/opi.r

opiCloseR Documentation

Calls opiClose_for_MACHINE as appropriate.

Description

Specific parameters and return values can be seen in the machine specific versions listed below in the ’See Also’.

Usage

opiClose()

Value

Each implementation should(!) return a list with at least the following elements:

  • err NULL if no error, otherwise a string describing the error.

See Also

opiClose_for_Compass(), opiClose_for_Octopus900(), opiClose_for_ImoVifa(), opiClose_for_PhoneHMD(), opiClose_for_Display(), opiClose_for_PicoVR(), opiClose_for_SimNo(), opiClose_for_SimYes(), opiClose_for_SimHenson(), opiClose_for_SimHensonRT(), opiClose_for_SimGaussian(), opiClose_for_Envision()


OPI documentation built on March 4, 2026, 9:08 a.m.