opiInitialise_for_Envision: Implementation of opiInitialise for the Envision HMP.

View source: R/Envision.r

opiInitialise_for_EnvisionR Documentation

Implementation of opiInitialise for the Envision HMP.

Description

This is for internal use only. Use opiInitialise() after chooseOPI("Envision") to call this function.

Arguments

address

A list containing:

  • port TCP port of the Envision's OPI.

  • ip IP Address of the Envision's OPI.

Details

port can take on values in the range [0, 65535].

Value

A list containing:

  • err NULL if there was no error, a string message if there is an error.

See Also

opiInitialise()

Examples

## Not run: 
chooseOpi("Envision")
result <- opiInitialise(address = list(port = 50001, ip = "localhost"))

## End(Not run)


OPI documentation built on March 4, 2026, 9:08 a.m.