opiPresent_for_Envision: Implementation of opiPresent for the Envision HMP.

View source: R/Envision.r

opiPresent_for_EnvisionR Documentation

Implementation of opiPresent for the Envision HMP.

Description

This is for internal use only. Use opiPresent() after chooseOPI("Envision") to call this function.

Arguments

stim

A list containing:

  • eye Eye where to present the stimulus

  • x x-coordinate

  • y y-coordinate

  • sx Size in the x-axis (diameter for circles).

  • sy (Optional) Size in the y-axis (diameter for circles). Defaults to sx

  • level Stimulus level

  • theta (Optional) Stimulus rotation from 0 to 360 degrees. Defaults to 0

  • t (Optional) Stimulus presentation time. Defaults to 200 ms

  • window (Optional) Response window. Defaults to 1500 ms

...

Parameters for other opiPresent implementations that are ignored here.

Value

A list containing:

  • err NULL if there was no error, a string message if there is an error. If there was no error the the following fields are also returned.

  • stamp Time stamp of stimulus onset.

  • time Response time from stimulus onset if button pressed (ms).

  • seen TRUE if seen, FALSE if not.

  • lpupil, rpupil Fixation positions (x, y), and diameter (d) for both left (lpupil) and right pupils (rpupil).

See Also

opiPresent()

Examples

## Not run: 
chooseOpi("Envision")
opiInitialise(address = list(port = 50001, ip = "localhost"))
result <- opiPresent(stim = list(eye = "os", x = 5, y = 4, sx = 0.43, level = 0))

## End(Not run)


OPI documentation built on March 4, 2026, 9:08 a.m.