opiQueryDevice_for_Compass: Implementation of opiQueryDevice for the Compass machine.

View source: R/Compass.r

opiQueryDevice_for_CompassR Documentation

Implementation of opiQueryDevice for the Compass machine.

Description

This is for internal use only. Use opiQueryDevice() with these Arguments and you will get the Value back.

Value

A list containing constants and their values used in the OPI Compass module.


OPI documentation built on March 4, 2026, 9:08 a.m.