opiQueryDevice_for_Envision: Implementation of opiQueryDevice for the Envision HMP.

View source: R/Envision.r

opiQueryDevice_for_EnvisionR Documentation

Implementation of opiQueryDevice for the Envision HMP.

Description

This is for internal use only. Use opiQueryDevice() after chooseOPI("Envision") to call this function.

Details

specs is a list containing:

  • hardware String with the Hardware name.

  • screens Whether the hardware has 1 screen (for both eyes) or 2 (1 for each).

  • fov A list with the field of view for x-axis (x) and y-axis (y).

  • resolution A list with the resolution for width (w) and height (h).

  • ipd A list with min (min) and max (max) possible IPDs and the current value (val).

  • depth Display's bit depth.

  • refresh Display's refresh rate.

  • domain An array of feasible dB values by the hardware.

settings is a list containing:

  • bgeye The eye where the background is shown ("OD", "OS", "OU").

  • bglum Background luminance in cd/m2.

  • fixeye The eye where a fixation target is shown ("OD", "OS", "OU").

  • fixlum Fixation luminance in cd/m2.

  • fixtarget Fixation target.

  • fixcx Fixation x-coordinate.

  • fixcy Fixation y-coordinate.

  • fixdx Fixation size in the x-axis (diameter for circles).

  • fixdy Fixation size in the y-axis (diameter for circles).

  • fixtheta Fixation rotation in degrees.

  • tracking Whether active correction is active.

Value

A list containing:

  • err NULL if there was no error, a string message if there is an error.

  • specs A list with specifications (see Details) if there was no error.

  • settings A list with the settings (see Details) if there was no error.

See Also

opiQueryDevice()

Examples

## Not run: 
chooseOpi("Envision")
opiInitialise(address = list(port = 50001, ip = "localhost"))
opiSetup(list(eye = "BOTH"))
result <- opiQueryDevice()

## End(Not run)


OPI documentation built on March 4, 2026, 9:08 a.m.