opiQueryDevice_for_MAIA: Implementation of opiQueryDevice for the MAIA machine.

View source: R/MAIA.r

opiQueryDevice_for_MAIAR Documentation

Implementation of opiQueryDevice for the MAIA machine.

Description

This is for internal use only. Use opiQueryDevice() with these Arguments and you will get the Value back.

Value

A list containing constants and their values used in the OPI MAIA module.


OPI documentation built on March 4, 2026, 9:08 a.m.