Learn R Programming

OPI (version 3.1.1)

opiSetup_for_Envision: Implementation of opiSetup for the Envision HMP.

Description

This is for internal use only. Use opiSetup() after chooseOPI("Envision") to call this function.

Value

A list containing:

  • err NULL if there was no error, a string message if there is an error.

Arguments

settings

A list containing:

  • bgeye The eye where the background is shown ("OD", "OS", "OU"). Default is "OU".

  • bglum Background luminance in cd/m2. Default is 10.

  • fixeye The eye where a fixation target is shown ("OD", "OS", "OU"). Default is "OU".

  • fixlum Fixation luminance in cd/m2. Default is 20.

  • fixtarget Fixation target. Default is "CROSS".

  • fixcx Fixation x-coordinate. Default is 0.

  • fixcy Fixation y-coordinate. Default is 0.

  • fixdx Fixation size in the x-axis (diameter for circles). Default is 2.

  • fixdy Fixation size in the y-axis (diameter for circles). Default is 2.

  • fixtheta Fixation rotation in degrees. Default is 0.

  • tracking Whether active correction is active. Default is False.

Details

All fields are optional. Missing fields will be assigned their Default value. opiSetup() sets all to default.

See Also

opiSetup()

Examples

Run this code
if (FALSE) {
chooseOpi("Envision")
opiInitialise(address = list(port = 50001, ip = "localhost"))
result <- opiSetup(settings = list(eye = "BOTH"))
}

Run the code above in your browser using DataLab