| opiClose_for_Compass | R Documentation |
This is for internal use only. Use opiClose() with
these Arguments and you will get the Value back.
WARNING: as at Feb 2026, this will only return data once per
Exam initiated on the Compass machine. If you want data
returned after one opiClose call, "Stop Exam" on the Compass machine
and create a new Exam. opiInitialise etc will still work as
normal if you start a second session with the same Exam, but
no data will be returned by opiClose.
A list with elements
err, which is an error code, NULL for no error
fixations, which is a matrix one row per fixation and three columns:
time (same as time_hw in opiPresent)
x (degrees relative to the centre of the image returned by opiInitialise - not the PRL)
y (as for x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.