| opiPresent_for_Envision | R Documentation |
This is for internal use only. Use opiPresent() after
chooseOPI("Envision") to call this function.
stim |
A list containing:
|
... |
Parameters for other opiPresent implementations that are ignored here. |
A list containing:
err NULL if there was no error, a string message if there is an error.
If there was no error the the following fields are also returned.
stamp Time stamp of stimulus onset.
time Response time from stimulus onset if button pressed (ms).
seen TRUE if seen, FALSE if not.
lpupil, rpupil Fixation positions (x, y), and diameter (d)
for both left (lpupil) and right pupils (rpupil).
opiPresent()
## Not run:
chooseOpi("Envision")
opiInitialise(address = list(port = 50001, ip = "localhost"))
result <- opiPresent(stim = list(eye = "os", x = 5, y = 4, sx = 0.43, level = 0))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.