powered by
This is for internal use only. Use opiPresent() after chooseOPI("Envision") to call this function.
opiPresent()
chooseOPI("Envision")
A list containing:
err NULL if there was no error, a string message if there is an error. If there was no error the the following fields are also returned.
err
NULL
stamp Time stamp of stimulus onset.
stamp
time Response time from stimulus onset if button pressed (ms).
time
seen TRUE if seen, FALSE if not.
seen
TRUE
FALSE
lpupil, rpupil Fixation positions (x, y), and diameter (d) for both left (lpupil) and right pupils (rpupil).
lpupil
rpupil
x
y
d
eye Eye where to present the stimulus
eye
x x-coordinate
y y-coordinate
sx Size in the x-axis (diameter for circles).
sx
sy (Optional) Size in the y-axis (diameter for circles). Defaults to sx
sy
level Stimulus level
level
theta (Optional) Stimulus rotation from 0 to 360 degrees. Defaults to 0
theta
t (Optional) Stimulus presentation time. Defaults to 200 ms
t
window (Optional) Response window. Defaults to 1500 ms
window
Parameters for other opiPresent implementations that are ignored here.
if (FALSE) { chooseOpi("Envision") opiInitialise(address = list(port = 50001, ip = "localhost")) result <- opiPresent(stim = list(eye = "os", x = 5, y = 4, sx = 0.43, level = 0)) }
Run the code above in your browser using DataLab