Learn R Programming

OPI (version 3.1.1)

opiQueryDevice_for_MAIA: Implementation of opiQueryDevice for the MAIA machine.

Description

This is for internal use only. Use opiQueryDevice() with these Arguments and you will get the Value back.

Arguments

Value

A list containing constants and their values used in the OPI MAIA module.